@@ -170,8 +170,11 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             if len(self.impuestos_trasladados) > 0:
                 traslados = self.dom.createElement('cfdi:Traslados')
                 total_traslados = 0
+                diferente_exento = 0
                 for traslado in self.impuestos_trasladados:
                     total_traslados += float(traslado.get('importe'))
+                    if traslado.get('tipo_factor') != 'Exento':
+                        diferente_exento += 1
                     traslados.appendChild(self.get_traslados(traslado))
                 impuestos.appendChild(traslados)
                 impuestos.setAttribute('TotalImpuestosTrasladados', str(total_traslados))
@@ -341,8 +344,9 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
         traslado.setAttribute('Base', str(traslado_data.get('base')))  # Importe del concepto
         traslado.setAttribute('Impuesto', traslado_data.get('impuesto', ''))
         traslado.setAttribute('TipoFactor', traslado_data.get('tipo_factor', 'Tasa'))  # Tipo factor Tasa ó Cuota
-        traslado.setAttribute('TasaOCuota', str(traslado_data.get('tasa_cuota')))  # valor del impuesto que se envia
-        traslado.setAttribute('Importe', str(traslado_data.get('importe')))
+        if traslado_data.get('tipo_factor') != 'Exento':
+            traslado.setAttribute('TasaOCuota', str(traslado_data.get('tasa_cuota')))  # valor del impuesto que se envia
+            traslado.setAttribute('Importe', str(traslado_data.get('importe')))
         return traslado
 
     def get_retenciones_concepto(self, retencion_data):
@@ -350,8 +354,9 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
         retencion.setAttribute('Base', str(retencion_data.get('base')))  # Importe del concepto
         retencion.setAttribute('Impuesto', retencion_data.get('impuesto'))
         retencion.setAttribute('TipoFactor', retencion_data.get('tipo_factor', 'Tasa'))  # Tipo factor Tasa ó Cuota
-        retencion.setAttribute('TasaOCuota', str(retencion_data.get('tasa_cuota')))  # valor del impuesto que se envia
-        retencion.setAttribute('Importe', str(retencion_data.get('importe')))
+        if retencion_data.get('tipo_factor') != 'Exento':
+            retencion.setAttribute('TasaOCuota', str(retencion_data.get('tasa_cuota')))  # valor del impuesto que se envia
+            retencion.setAttribute('Importe', str(retencion_data.get('importe')))
         return retencion
 
     def get_informacion_aduanera(self, informacion_aduanera):
