@@ -1,10 +1,12 @@
 # -*- encoding: utf-8 -*-
-
+import json
 from abc import abstractmethod, ABCMeta
 from base64 import b64encode, b64decode
 
 from xml.dom.minidom import parse
 from xml.etree import ElementTree
+
+import xmltodict
 from lxml import etree
 from lxml.etree import XSLTParseError
 
@@ -149,6 +151,15 @@ class AbstractGeneratorXml(object):
         """
         return self.cadena_original_value
 
+    def get_xml_data(self, xml):
+        """
+        Recibe xml en formato str y retorna un json del xml
+        :param xml:
+        :return: xml_json
+        """
+        obj = xmltodict.parse(xml)
+        return json.dumps(obj)
+
     def get_datos(self, xml):
         xml_info = self.get_xml_info(xml)
         return {
